@@ -35,6 +35,7 @@ class State:
     def __init__(self,
                  value: int,
                  *callbacks: Callable,
+                 alias: str = None,
                  ):
         """
         Custom state definition with additional support. An integer value must be specified, and callbacks are supported.
@@ -42,8 +43,10 @@ class State:
 
         :param value: state value
         :param callbacks: callback functions. These functions should take no arguments.
+        :param alias: name alias for convenience
         """
         self.value = value
+        self.alias = alias
         self.pre_state_callbacks = list(callbacks)
         self.post_state_callbacks = []
 
@@ -212,6 +215,18 @@ class StateSet(Enum):
         """whether the value has callbacks registered"""
         return self.has_post_state_change_callbacks or self.has_pre_state_change_callbacks
 
+    def get_name(self) -> str:
+        """retrieves the name or alias of the state"""
+        if isinstance(self.value, State):
+            return self.value.alias or self._name_
+        return self.name
+
+    def set_alias(self, alias: str = None):
+        """sets the alias for the StateSet instance"""
+        if isinstance(self.value, State) is False:
+            raise TypeError(f'the {self.__class__.__name__} value is not a State instance')
+        self.value.alias = alias
+
     def register_callbacks(self, *callbacks: Callable, pre_state: bool = True):
         """
         Pass through for registering callbacks with the associated State instance. These callbacks will be executed
