@@ -377,6 +377,26 @@ class TestComponentCallbacks(unittest.TestCase):
         """special callback which should be executed after a component state is changed"""
         self.assertEqual(self.component.current_action_state, 1)
 
+    def test_alias_setting(self):
+        """tests alias setting for a state"""
+        state = State(1, alias='banana')
+        self.assertEqual(state.alias, 'banana', 'test alias was set from instantiation')
+        state.alias = 'melon'
+        self.assertEqual(state.alias, 'melon', 'test alias updating')
+
+        class TestStateSet(StateSet):
+            MELON = State(1)
+            BANANA = 2
+
+        test_state = TestStateSet(1)
+        self.assertEqual(test_state.name, 'MELON', 'test base name')
+        self.assertEqual(test_state.get_name(), 'MELON', 'test default')
+        self.assertEqual(TestStateSet(2).get_name(), 'BANANA', 'test name retrieval from integer')
+        test_state.set_alias('delicious')
+        self.assertEqual(test_state.value.alias, 'delicious', 'test alias setting passthrough')
+        self.assertEqual(test_state.get_name(), 'delicious', 'test name retrieval is updated')
+
+
     def test_action_callback_ordering(self):
         """
         tests that pre- and post- operational state change callbacks are executed in the correct place
